@@ -1,7 +1,8 @@
 import express from 'express';
 import asyncHandler from 'express-async-handler';
-import { QueryTypes } from 'sequelize';
+import { Op, QueryTypes } from 'sequelize';
 import { simpleGet, simplePost, simplePut } from '@tamanu/shared/utils/crudHelpers';
+import { VISIBILITY_STATUSES } from '@tamanu/constants';
 
 export const locationGroup = express.Router();
 
@@ -15,8 +16,10 @@ locationGroup.get(
     const { facilityId } = req.query;
     const locationGroups = await req.models.LocationGroup.findAll({
       where: {
-        facilityId,
+        facilityId: facilityId ?? { [Op.ne]: null },
+        visibilityStatus: VISIBILITY_STATUSES.CURRENT,
       },
+      order: [['name', 'ASC']],
     });
     res.send(locationGroups);
   }),
@@ -164,7 +167,7 @@ locationGroup.get(
       },
     );
 
-    const data = results.map(item => ({
+    const data = results.map((item) => ({
       location: item.location,
       arrivalDate: item.arrival_date,
       patient: {
